==> wxWidgets-3.0.5-docs-html.tar.bz2: wxWidgets-3.0.5-docs-html/search/all_16.js <==
var searchData=
[
  ['validators',['Validators',['../group__group__class__validator.html',1,'']]],
  ['virtual_20file_20system',['Virtual File System',['../group__group__class__vfs.html',1,'']]],
  ['versioning',['Versioning',['../group__group__funcmacro__version.html',1,'']]],
  ['valarritem',['ValArrItem',['../classwx_p_g_choices.html#ab5c3740cb0be35ee3f770f38dbd795e6',1,'wxPGChoices']]],
  ['valgen_2eh',['valgen.h',['../valgen_8h.html',1,'']]],
  ['validate',['Validate',['../classwx_data_view_renderer.html#a64c9df3410623498956ce5ed7524a9cf',1,'wxDataViewRenderer::Validate()'],['../classwx_numeric_property_validator.html#afc43c355089e62fde2fc202879a94cf1',1,'wxNumericPropertyValidator::Validate()'],['../classwx_validator.html#abe48368bac7f540f0c20b1436e5c71af',1,'wxValidator::Validate()'],['../classwx_text_validator.html#a19da7111800bc8aa5283fe9718943738',1,'wxTextValidator::Validate()'],['../classwx_window.html#ac87f253253a0c5eb498871c83afa40fd',1,'wxWindow::Validate()']]],
  ['validate_2eh',['validate.h',['../validate_8h.html',1,'']]],
  ['validatevalue',['ValidateValue',['../classwx_p_g_property.html#a2e0c041aa3e19a5934a02c65b53f9f7d',1,'wxPGProperty::ValidateValue()'],['../classwx_int_property.html#a642930118b1851d28c4e80dd07dc6548',1,'wxIntProperty::ValidateValue()'],['../classwx_u_int_property.html#a5d3cd6758d91946b766f40d23cf3659c',1,'wxUIntProperty::ValidateValue()'],['../classwx_float_property.html#ac1efa28c80ba221e81d0b4fb665e9470',1,'wxFloatProperty::ValidateValue()'],['../classwx_enum_property.html#ae273d64b8f289d3ee823db615d6cdc6b',1,'wxEnumProperty::ValidateValue()']]],
  ['validator_2eh',['validator.h',['../validator_8h.html',1,'']]],
  ['validhost',['ValidHost',['../classwx_d_d_e_client.html#ac10cacc5cd6c922607cd2087a281de08',1,'wxDDEClient::ValidHost()'],['../classwx_client.html#a532e7914e2e5aa79ef770521e0257108',1,'wxClient::ValidHost()'],['../classwx_t_c_p_client.html#a28baa6e6538ca2d9bb521b0ac1ece870',1,'wxTCPClient::ValidHost()']]],
  ['valnum_2eh',['valnum.h',['../valnum_8h.html',1,'']]],
  ['valtext_2eh',['valtext.h',['../valtext_8h.html',1,'']]],
  ['value',['value',['../classwx_image_1_1_h_s_v_value.html#a403d5a5cf298a0084c870ca07953e56e',1,'wxImage::HSVValue']]],
  ['value_5ftype',['value_type',['../classwx_stack_3_01_t_01_4.html#a9c1bedb7493896bc8e7bfa37c0b1673f',1,'wxStack&lt; T &gt;::value_type()'],['../classwx_string.html#a6abd360d5072ed411f80eda16ed0bd99',1,'wxString::value_type()'],['../classwx_uni_char.html#ac115911ed58b8a8d781307523c4c759c',1,'wxUniChar::value_type()'],['../classwx_vector_3_01_t_01_4.html#a200a710822fc0779945b7d5bf943d9cc',1,'wxVector&lt; T &gt;::value_type()']]],
  ['valuechanged',['ValueChanged',['../classwx_data_view_model.html#afc162ff0230dd026ef99591696cbfb86',1,'wxDataViewModel::ValueChanged()'],['../classwx_data_view_model_notifier.html#a0c99e0ae9e1becff0cdedc0a8f3374c4',1,'wxDataViewModelNotifier::ValueChanged()']]],
  ['valuefromint_5f',['ValueFromInt_',['../classwx_enum_property.html#a2aae103c2f1299078fa58449f8d61a85',1,'wxEnumProperty']]],
  ['valuefromstring_5f',['ValueFromString_',['../classwx_enum_property.html#a53ef6d6c787a7e838611158c49be4e24',1,'wxEnumProperty']]],
  ['valuetostring',['ValueToString',['../classwx_font_property.html#a5da95c6502542fbd773d0237fe81d6ae',1,'wxFontProperty::ValueToString()'],['../classwx_system_colour_property.html#a7078a7ea3e5ba4f17b983f74978ecb40',1,'wxSystemColourProperty::ValueToString()'],['../classwx_colour_property.html#a62606c861ee13eed3392c24c6f877070',1,'wxColourProperty::ValueToString()'],['../classwx_multi_choice_property.html#a03a4a39f27e1f7d1473386539c570c1e',1,'wxMultiChoiceProperty::ValueToString()'],['../classwx_date_property.html#ac9aa51f978f277e6a789e4d82f764316',1,'wxDateProperty::ValueToString()'],['../classwx_p_g_property.html#a7bef52444b2c03a4f10eef54ef9e9739',1,'wxPGProperty::ValueToString()'],['../classwx_property_category.html#ae89a5619a39e4d665d9ff34a52432582',1,'wxPropertyCategory::ValueToString()'],['../classwx_string_property.html#a2edbb0e989e54d9c495779138d18dc8a',1,'wxStringProperty::ValueToString()'],['../classwx_int_property.html#ab92d4883312adc4a1ad0d27c028174a9',1,'wxIntProperty::ValueToString()'],['../classwx_u_int_property.html#a588a109754deac904cb9cdf56b9bdcf7',1,'wxUIntProperty::ValueToString()'],['../classwx_float_property.html#aa196dea7eadeddfcc86731cea2cb67bf',1,'wxFloatProperty::ValueToString()'],['../classwx_bool_property.html#ada58f6cde3a2d0709affe6f997a80bda',1,'wxBoolProperty::ValueToString()'],['../classwx_enum_property.html#a64b2208356693a63dca67444fabbaa77',1,'wxEnumProperty::ValueToString()'],['../classwx_flags_property.html#a19e24b5f6649527745a7824f29b6386c',1,'wxFlagsProperty::ValueToString()'],['../classwx_file_property.html#a222e0b8281ab5af4baa85a3f5ba31ba4',1,'wxFileProperty::ValueToString()'],['../classwx_long_string_property.html#a2b22d52fcd7fc557bc1fadec7a5382d8',1,'wxLongStringProperty::ValueToString()'],['../classwx_array_string_property.html#a03ddfb03c71a858f8b45231e5b08075a',1,'wxArrayStringProperty::ValueToString()']]],
  ['valuetype',['ValueType',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448ae',1,'wxRegKey::ValueType()'],['../classwx_num_validator.html#a651c1cd4cf84fdcbecb201c474e22afe',1,'wxNumValidator::ValueType()'],['../classwx_integer_validator.html#a70544cb69a1ff43801668daa70ffa5ec',1,'wxIntegerValidator::ValueType()'],['../classwx_floating_point_validator.html#a75a7c2f5b92933247fa82a33dc3d2e62',1,'wxFloatingPointValidator::ValueType()']]],
  ['variant_2eh',['variant.h',['../variant_8h.html',1,'']]],
  ['vchome',['VCHome',['../classwx_styled_text_ctrl.html#a7f1a7f3ea35f58e5b9bc5227f5833400',1,'wxStyledTextCtrl']]],
  ['vchomeextend',['VCHomeExtend',['../classwx_styled_text_ctrl.html#af4e34f2bbdca94ccbd89960a7e765dd5',1,'wxStyledTextCtrl']]],
  ['vchomerectextend',['VCHomeRectExtend',['../classwx_styled_text_ctrl.html#a7675ef1a8905fad08e50d1c72fdfdfa5',1,'wxStyledTextCtrl']]],
  ['vchomewrap',['VCHomeWrap',['../classwx_styled_text_ctrl.html#ae2ae99a185d56fe6b9b631c099e1ca55',1,'wxStyledTextCtrl']]],
  ['vchomewrapextend',['VCHomeWrapExtend',['../classwx_styled_text_ctrl.html#ae56149308008de97ad52f2cc0fbc3834',1,'wxStyledTextCtrl']]],
  ['vector_2eh',['vector.h',['../vector_8h.html',1,'']]],
  ['version',['version',['../structwx_renderer_version.html#ab91a12e1c5def44a3f3d08a744094c55',1,'wxRendererVersion']]],
  ['version_2eh',['version.h',['../version_8h.html',1,'']]],
  ['versioninfo_2eh',['versioninfo.h',['../versioninfo_8h.html',1,'']]],
  ['verticalcentrecaret',['VerticalCentreCaret',['../classwx_styled_text_ctrl.html#a80613b707f38ea1652460abbc8eb3ec0',1,'wxStyledTextCtrl']]],
  ['veto',['Veto',['../classwx_aui_manager_event.html#a047b8f9e45d34658a11df8cea0255820',1,'wxAuiManagerEvent::Veto()'],['../classwx_notify_event.html#a49e4502414a11e273f51a34a21d2acd3',1,'wxNotifyEvent::Veto()'],['../classwx_close_event.html#a0ec337c77613d5d8407831cd64e16417',1,'wxCloseEvent::Veto()'],['../classwx_power_event.html#a63524192bffa8c3140b90c3f842ca995',1,'wxPowerEvent::Veto()'],['../classwx_property_grid_event.html#a5e35bf2aeaad48147c0270e9b04426c8',1,'wxPropertyGridEvent::Veto()']]],
  ['vidmode_2eh',['vidmode.h',['../vidmode_8h.html',1,'']]],
  ['virtualheightchanged',['VirtualHeightChanged',['../classwx_property_grid_page_state.html#a317168d90819366d5a9ee57bacefd382',1,'wxPropertyGridPageState']]],
  ['virtualhittest',['VirtualHitTest',['../classwx_var_scroll_helper_base.html#ab17ffa8dd9790d7ffc789ea080816518',1,'wxVarScrollHelperBase::VirtualHitTest()'],['../classwx_var_h_v_scroll_helper.html#a2277e6863f80d65e349aa08993aa166a',1,'wxVarHVScrollHelper::VirtualHitTest(wxCoord x, wxCoord y) const '],['../classwx_var_h_v_scroll_helper.html#a263852506a3cf9f33859f5412bd784ec',1,'wxVarHVScrollHelper::VirtualHitTest(const wxPoint &amp;pos) const ']]],
  ['visiblefromdocline',['VisibleFromDocLine',['../classwx_styled_text_ctrl.html#a7fce59582d5c0d1100860f4f2c7aeac0',1,'wxStyledTextCtrl']]],
  ['vlbox_2eh',['vlbox.h',['../vlbox_8h.html',1,'']]],
  ['volume_2eh',['volume.h',['../volume_8h.html',1,'']]],
  ['vscroll_2eh',['vscroll.h',['../vscroll_8h.html',1,'']]]
];

==> wxWidgets-3.1.0-docs-html.tar.bz2: wxWidgets-3.1.0-docs-html/search/all_16.js <==
var searchData=
[
  ['validators',['Validators',['../group__group__class__validator.html',1,'']]],
  ['virtual_20file_20system',['Virtual File System',['../group__group__class__vfs.html',1,'']]],
  ['versioning',['Versioning',['../group__group__funcmacro__version.html',1,'']]],
  ['valarritem',['ValArrItem',['../classwx_p_g_choices.html#ab5c3740cb0be35ee3f770f38dbd795e6',1,'wxPGChoices']]],
  ['valgen_2eh',['valgen.h',['../valgen_8h.html',1,'']]],
  ['validate',['Validate',['../classwx_data_view_renderer.html#a64c9df3410623498956ce5ed7524a9cf',1,'wxDataViewRenderer::Validate()'],['../classwx_validator.html#abe48368bac7f540f0c20b1436e5c71af',1,'wxValidator::Validate()'],['../classwx_text_validator.html#a19da7111800bc8aa5283fe9718943738',1,'wxTextValidator::Validate()'],['../classwx_window.html#ac87f253253a0c5eb498871c83afa40fd',1,'wxWindow::Validate()']]],
  ['validate_2eh',['validate.h',['../validate_8h.html',1,'']]],
  ['validatevalue',['ValidateValue',['../classwx_p_g_property.html#a2e0c041aa3e19a5934a02c65b53f9f7d',1,'wxPGProperty']]],
  ['validator_2eh',['validator.h',['../validator_8h.html',1,'']]],
  ['validhost',['ValidHost',['../classwx_d_d_e_client.html#ac10cacc5cd6c922607cd2087a281de08',1,'wxDDEClient::ValidHost()'],['../classwx_client.html#a532e7914e2e5aa79ef770521e0257108',1,'wxClient::ValidHost()'],['../classwx_t_c_p_client.html#a28baa6e6538ca2d9bb521b0ac1ece870',1,'wxTCPClient::ValidHost()']]],
  ['valnum_2eh',['valnum.h',['../valnum_8h.html',1,'']]],
  ['valtext_2eh',['valtext.h',['../valtext_8h.html',1,'']]],
  ['value',['value',['../classwx_image_1_1_h_s_v_value.html#a403d5a5cf298a0084c870ca07953e56e',1,'wxImage::HSVValue']]],
  ['value_5ftype',['value_type',['../classwx_stack_3_01_t_01_4.html#a9c1bedb7493896bc8e7bfa37c0b1673f',1,'wxStack&lt; T &gt;::value_type()'],['../classwx_string.html#a6abd360d5072ed411f80eda16ed0bd99',1,'wxString::value_type()'],['../classwx_uni_char.html#ac115911ed58b8a8d781307523c4c759c',1,'wxUniChar::value_type()'],['../classwx_vector_3_01_t_01_4.html#a200a710822fc0779945b7d5bf943d9cc',1,'wxVector&lt; T &gt;::value_type()']]],
  ['valuechanged',['ValueChanged',['../classwx_data_view_model.html#a29418c077b554d0e87d509806fffc67d',1,'wxDataViewModel::ValueChanged()'],['../classwx_data_view_model_notifier.html#a0c99e0ae9e1becff0cdedc0a8f3374c4',1,'wxDataViewModelNotifier::ValueChanged()']]],
  ['valuetostring',['ValueToString',['../classwx_p_g_property.html#a7bef52444b2c03a4f10eef54ef9e9739',1,'wxPGProperty']]],
  ['valuetype',['ValueType',['../classwx_reg_key.html#a50c331bab4eb972c283eeaf59fc448ae',1,'wxRegKey::ValueType()'],['../classwx_num_validator.html#a651c1cd4cf84fdcbecb201c474e22afe',1,'wxNumValidator::ValueType()'],['../classwx_integer_validator.html#a70544cb69a1ff43801668daa70ffa5ec',1,'wxIntegerValidator::ValueType()'],['../classwx_floating_point_validator.html#a75a7c2f5b92933247fa82a33dc3d2e62',1,'wxFloatingPointValidator::ValueType()']]],
  ['variant_2eh',['variant.h',['../variant_8h.html',1,'']]],
  ['vchome',['VCHome',['../classwx_styled_text_ctrl.html#a7f1a7f3ea35f58e5b9bc5227f5833400',1,'wxStyledTextCtrl']]],
  ['vchomedisplay',['VCHomeDisplay',['../classwx_styled_text_ctrl.html#a1d2cb8b1b0cf64e96f56674678eec841',1,'wxStyledTextCtrl']]],
  ['vchomedisplayextend',['VCHomeDisplayExtend',['../classwx_styled_text_ctrl.html#a68fcb72c91829dd5d6d2235003bcd8f8',1,'wxStyledTextCtrl']]],
  ['vchomeextend',['VCHomeExtend',['../classwx_styled_text_ctrl.html#af4e34f2bbdca94ccbd89960a7e765dd5',1,'wxStyledTextCtrl']]],
  ['vchomerectextend',['VCHomeRectExtend',['../classwx_styled_text_ctrl.html#a7675ef1a8905fad08e50d1c72fdfdfa5',1,'wxStyledTextCtrl']]],
  ['vchomewrap',['VCHomeWrap',['../classwx_styled_text_ctrl.html#ae2ae99a185d56fe6b9b631c099e1ca55',1,'wxStyledTextCtrl']]],
  ['vchomewrapextend',['VCHomeWrapExtend',['../classwx_styled_text_ctrl.html#ae56149308008de97ad52f2cc0fbc3834',1,'wxStyledTextCtrl']]],
  ['vector_2eh',['vector.h',['../vector_8h.html',1,'']]],
  ['version',['version',['../structwx_renderer_version.html#ab91a12e1c5def44a3f3d08a744094c55',1,'wxRendererVersion']]],
  ['version_2eh',['version.h',['../version_8h.html',1,'']]],
  ['versioninfo_2eh',['versioninfo.h',['../versioninfo_8h.html',1,'']]],
  ['verticalcentrecaret',['VerticalCentreCaret',['../classwx_styled_text_ctrl.html#a80613b707f38ea1652460abbc8eb3ec0',1,'wxStyledTextCtrl']]],
  ['veto',['Veto',['../classwx_aui_manager_event.html#a047b8f9e45d34658a11df8cea0255820',1,'wxAuiManagerEvent::Veto()'],['../classwx_notify_event.html#a49e4502414a11e273f51a34a21d2acd3',1,'wxNotifyEvent::Veto()'],['../classwx_close_event.html#a0ec337c77613d5d8407831cd64e16417',1,'wxCloseEvent::Veto()'],['../classwx_power_event.html#a63524192bffa8c3140b90c3f842ca995',1,'wxPowerEvent::Veto()'],['../classwx_property_grid_event.html#a5e35bf2aeaad48147c0270e9b04426c8',1,'wxPropertyGridEvent::Veto()']]],
  ['vidmode_2eh',['vidmode.h',['../vidmode_8h.html',1,'']]],
  ['virtualhittest',['VirtualHitTest',['../classwx_var_scroll_helper_base.html#ab17ffa8dd9790d7ffc789ea080816518',1,'wxVarScrollHelperBase::VirtualHitTest()'],['../classwx_var_h_v_scroll_helper.html#a2277e6863f80d65e349aa08993aa166a',1,'wxVarHVScrollHelper::VirtualHitTest(wxCoord x, wxCoord y) const '],['../classwx_var_h_v_scroll_helper.html#a263852506a3cf9f33859f5412bd784ec',1,'wxVarHVScrollHelper::VirtualHitTest(const wxPoint &amp;pos) const ']]],
  ['visiblefromdocline',['VisibleFromDocLine',['../classwx_styled_text_ctrl.html#a7fce59582d5c0d1100860f4f2c7aeac0',1,'wxStyledTextCtrl']]],
  ['vlbox_2eh',['vlbox.h',['../vlbox_8h.html',1,'']]],
  ['volume_2eh',['volume.h',['../volume_8h.html',1,'']]],
  ['vscroll_2eh',['vscroll.h',['../vscroll_8h.html',1,'']]]
];
